pub enum ByteError {
ValueIncorrect,
UnitIncorrect,
ParseError,
}Expand description
Different error types for Byte.
Variants
ValueIncorrect
The value used for creating a Byte object is incorrect. (from_unit, from_string)
UnitIncorrect
The unit used for creating a Byte object is incorrect. (from_string)
ParseError
The string used for creating a Byte object is incorrect. (from_string)