pub struct Byte(_);Expand description
Represent the n-bytes data. Use associated functions: from_unit, from_bytes, from_string, to create the instance.
Implementations
sourceimpl Byte
impl Byte
sourcepub fn from_unit(value: f64, unit: ByteUnit) -> Result<Byte, ByteError>
pub fn from_unit(value: f64, unit: ByteUnit) -> Result<Byte, ByteError>
Create a new Byte object from a specified value and a unit. Accuracy should be taken care of.
Examples
extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let result = Byte::from_unit(1500f64, ByteUnit::KB).unwrap();
assert_eq!(result.get_bytes(), 1500000u128);sourcepub fn from_bytes(bytes: u128) -> Byte
pub fn from_bytes(bytes: u128) -> Byte
Create a new Byte object from bytes.
Examples
extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let result = Byte::from_bytes(1500000u128);
assert_eq!(result.get_bytes(), 1500000u128);sourcepub fn from_string<S: AsRef<str>>(string: S) -> Result<Byte, ByteError>
pub fn from_string<S: AsRef<str>>(string: S) -> Result<Byte, ByteError>
Create a new Byte object from string. Accuracy should be taken care of.
Examples
extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let result = Byte::from_string("123KiB").unwrap();
assert_eq!(result, Byte::from_unit(123f64, ByteUnit::KiB).unwrap());extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let result = Byte::from_string("50.84 MB").unwrap();
assert_eq!(result, Byte::from_unit(50.84f64, ByteUnit::MB).unwrap());extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let result = Byte::from_string("8 b").unwrap(); // 8 bits
assert_eq!(result.get_bytes(), 1u128);sourcepub fn get_bytes(&self) -> u128
pub fn get_bytes(&self) -> u128
Get bytes represented by a Byte object.
Examples
extern crate byte_unit;
use byte_unit::Byte;
let byte = Byte::from_string("123KiB").unwrap();
let result = byte.get_bytes();
assert_eq!(result, 125952);extern crate byte_unit;
use byte_unit::Byte;
let byte = Byte::from_string("50.84 MB").unwrap();
let result = byte.get_bytes();
assert_eq!(result, 50840000);sourcepub fn get_appropriate_unit(&self, binary_multiples: bool) -> AdjustedByte
pub fn get_appropriate_unit(&self, binary_multiples: bool) -> AdjustedByte
Find the appropriate unit and value for Byte object. Accuracy should be taken care of.
Examples
extern crate byte_unit;
use byte_unit::Byte;
let byte = Byte::from_string("123KiB").unwrap();
let adjusted_byte = byte.get_appropriate_unit(false);
assert_eq!(adjusted_byte.to_string(), "125.95 KB");extern crate byte_unit;
use byte_unit::Byte;
let byte = Byte::from_string("50.84 MB").unwrap();
let adjusted_byte = byte.get_appropriate_unit(true);
assert_eq!(adjusted_byte.to_string(), "48.48 MiB");sourcepub fn get_adjusted_unit(&self, unit: ByteUnit) -> AdjustedByte
pub fn get_adjusted_unit(&self, unit: ByteUnit) -> AdjustedByte
Adjust the unit and value for Byte object. Accuracy should be taken care of.
Examples
extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let byte = Byte::from_string("123KiB").unwrap();
let adjusted_byte = byte.get_adjusted_unit(ByteUnit::KB);
assert_eq!(adjusted_byte.to_string(), "125.95 KB");extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let byte = Byte::from_string("50.84 MB").unwrap();
let adjusted_byte = byte.get_adjusted_unit(ByteUnit::MiB);
assert_eq!(adjusted_byte.to_string(), "48.48 MiB");Trait Implementations
sourceimpl PartialEq<Byte> for Byte
impl PartialEq<Byte> for Byte
sourcefn eq(&self, other: &Byte) -> bool
fn eq(&self, other: &Byte) -> bool
Deal with the logical numeric equivalent.
Examples
extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let byte1 = Byte::from_unit(1024f64, ByteUnit::KiB).unwrap();
let byte2 = Byte::from_unit(1024f64, ByteUnit::KiB).unwrap();
assert_eq!(byte1, byte2);extern crate byte_unit;
use byte_unit::{Byte, ByteUnit};
let byte1 = Byte::from_unit(1024f64, ByteUnit::KiB).unwrap();
let byte2 = Byte::from_unit(1f64, ByteUnit::MiB).unwrap();
assert_eq!(byte1, byte2);Auto Trait Implementations
impl RefUnwindSafe for Byte
impl Send for Byte
impl Sync for Byte
impl Unpin for Byte
impl UnwindSafe for Byte